@@ -8,6 +8,7 @@
 #include "protos/action.h"
 #include "protos/files.h"
 #include "protos/glob.h"
+#include "protos/globals.h"
 #include "protos/llist.h"
 #include "protos/print.h"
 #include "protos/parse.h"
@@ -15,46 +16,38 @@
 #include "protos/variables.h"
 
 
-extern struct session *activesession, *nullsession;
-extern pvars_t *pvars;  /* the %0, %1, %2,....%9 variables */
-extern int term_echoing;
-extern char tintin_char;
-extern int acnum;
-extern int in_alias;
-int var_len[10];
-char *var_ptr[10];
-extern int aborting, recursion;
+static int var_len[10];
+static const char *var_ptr[10];
 
-int inActions=0;
-int deletedActions=0;
-char *match_start,*match_end;
+static bool inActions=false;
+static int deletedActions=0;
+const char *match_start, *match_end;
 
-extern struct session *if_command(char *arg, struct session *ses);
-static int check_a_action(char *line, char *action, int inside, struct session *ses);
+extern struct session *if_command(const char *arg, struct session *ses);
+static bool check_a_action(const char *line, const char *action, bool inside, struct session *ses);
 
-static int kill_action(struct listnode *head,struct listnode *nptr)
+static void kill_action(struct listnode *head, struct listnode *nptr)
 {
     if (inActions)
     {
-        if (!strcmp(nptr->left,K_ACTION_MAGIC))
-            return 0;
+        if (!strcmp(nptr->left, K_ACTION_MAGIC))
+            return;
         SFREE(nptr->left);
         nptr->left=MALLOC(strlen(K_ACTION_MAGIC)+1);
-        strcpy(nptr->left,K_ACTION_MAGIC);
+        strcpy(nptr->left, K_ACTION_MAGIC);
         deletedActions++;
     }
     else
-        deletenode_list(head,nptr);
-    return 1;
+        deletenode_list(head, nptr);
 }
 
 static void zap_actions(struct session *ses)
 {
-    struct listnode *l,*ln,*ol;
+    struct listnode *l, *ln, *ol;
 
     ln =(ol=ses->actions)->next;
     while (ln)
-        if (strcmp(ln->left,K_ACTION_MAGIC))
+        if (strcmp(ln->left, K_ACTION_MAGIC))
             ln=(ol=ln)->next;
         else
         {
@@ -67,7 +60,7 @@ static void zap_actions(struct session *ses)
         }
     ln =(ol=ses->prompts)->next;
     while (ln)
-        if (strcmp(ln->left,K_ACTION_MAGIC))
+        if (strcmp(ln->left, K_ACTION_MAGIC))
             ln=(ol=ln)->next;
         else
         {
@@ -87,12 +80,12 @@ static void zap_actions(struct session *ses)
 
 /*  Priority code added by Joann Ellsworth 2/2/94 */
 
-void action_command(char *arg, struct session *ses)
+void action_command(const char *arg, struct session *ses)
 {
     char left[BUFFER_SIZE], right[BUFFER_SIZE];
     char pr[BUFFER_SIZE];
     struct listnode *myactions, *ln;
-    int flag;
+    bool flag;
 
     myactions = ses->actions;
     arg = get_arg_in_braces(arg, left, 0);
@@ -102,27 +95,25 @@ void action_command(char *arg, struct session *ses)
         strcpy(pr, "5"); /* defaults priority to 5 if no value given */
     if (!*left)
     {
-        tintin_printf(ses,"#Defined actions:");
+        tintin_printf(ses, "#Defined actions:");
         show_list_action(myactions);
-        prompt(ses);
     }
     else if (*left && !*right)
     {
-        flag=0;
+        flag=false;
         while ((myactions = search_node_with_wild(myactions, left)) != NULL)
-            if (strcmp(myactions->left,K_ACTION_MAGIC))
-                shownode_list_action(myactions), flag++;
-        if (!flag && ses->mesvar[1])
-            tintin_printf(ses,"#That action (%s) is not defined.",left);
-        prompt(ses);
+            if (strcmp(myactions->left, K_ACTION_MAGIC))
+                shownode_list_action(myactions), flag=true;
+        if (!flag && ses->mesvar[MSG_ACTION])
+            tintin_printf(ses, "#That action (%s) is not defined.", left);
     }
     else
     {
         if ((ln = searchnode_list(myactions, left)) != NULL)
             kill_action(myactions, ln);
         insertnode_list(myactions, left, right, pr, PRIORITY);
-        if (ses->mesvar[1])
-            tintin_printf(ses,"#Ok. {%s} now triggers {%s} @ {%s}", left, right, pr);
+        if (ses->mesvar[MSG_ACTION])
+            tintin_printf(ses, "#Ok. {%s} now triggers {%s} @ {%s}", left, right, pr);
         acnum++;
     }
 }
@@ -130,12 +121,12 @@ void action_command(char *arg, struct session *ses)
 /*****************************/
 /* the #promptaction command */
 /*****************************/
-void promptaction_command(char *arg, struct session *ses)
+void promptaction_command(const char *arg, struct session *ses)
 {
     char left[BUFFER_SIZE], right[BUFFER_SIZE];
     char pr[BUFFER_SIZE];
     struct listnode *myprompts, *ln;
-    int flag;
+    bool flag;
 
     myprompts = ses->prompts;
     arg = get_arg_in_braces(arg, left, 0);
@@ -145,27 +136,25 @@ void promptaction_command(char *arg, struct session *ses)
         strcpy(pr, "5"); /* defaults priority to 5 if no value given */
     if (!*left)
     {
-        tintin_printf(ses,"#Defined prompts:");
+        tintin_printf(ses, "#Defined prompts:");
         show_list_action(myprompts);
-        prompt(ses);
     }
     else if (*left && !*right)
     {
-        flag=0;
+        flag=false;
         while ((myprompts = search_node_with_wild(myprompts, left)))
-            if (strcmp(myprompts->left,K_ACTION_MAGIC))
-                shownode_list_action(myprompts), flag++;
-        if (!flag && ses->mesvar[1])
-            tintin_printf(ses,"#That promptaction (%s) is not defined.",left);
-        prompt(ses);
+            if (strcmp(myprompts->left, K_ACTION_MAGIC))
+                shownode_list_action(myprompts), flag=true;
+        if (!flag && ses->mesvar[MSG_ACTION])
+            tintin_printf(ses, "#That promptaction (%s) is not defined.", left);
     }
     else
     {
         if ((ln = searchnode_list(myprompts, left)) != NULL)
             kill_action(myprompts, ln);
         insertnode_list(myprompts, left, right, pr, PRIORITY);
-        if (ses->mesvar[1])
-            tintin_printf(ses,"#Ok. {%s} now triggers {%s} @ {%s}", left, right, pr);
+        if (ses->mesvar[MSG_ACTION])
+            tintin_printf(ses, "#Ok. {%s} now triggers {%s} @ {%s}", left, right, pr);
     }
 }
 
@@ -173,11 +162,11 @@ void promptaction_command(char *arg, struct session *ses)
 /*************************/
 /* the #unaction command */
 /*************************/
-void unaction_command(char *arg, struct session *ses)
+void unaction_command(const char *arg, struct session *ses)
 {
     char left[BUFFER_SIZE];
-    struct listnode **ptr,*ln;
-    int flag;
+    struct listnode **ptr, *ln;
+    bool flag=false;
 
     arg = get_arg_in_braces(arg, left, 1);
     if (!*left)
@@ -185,21 +174,20 @@ void unaction_command(char *arg, struct session *ses)
         tintin_eprintf(ses, "#Syntax: #unaction <pattern>");
         return;
     }
-    flag = 0;
     ptr = &ses->actions->next;
     while (*ptr)
     {
         ln=*ptr;
-        if (strcmp(ln->left,K_ACTION_MAGIC)&&match(left,ln->left))
+        if (strcmp(ln->left, K_ACTION_MAGIC)&&match(left, ln->left))
         {
-            flag=1;
-            if (ses->mesvar[1])
-                tintin_printf(ses,"#Ok. {%s} is no longer an action.", ln->left);
+            flag=true;
+            if (ses->mesvar[MSG_ACTION])
+                tintin_printf(ses, "#Ok. {%s} is no longer an action.", ln->left);
             SFREE(ln->left);
             if (inActions)
             {
                 ln->left=MALLOC(strlen(K_ACTION_MAGIC)+1);
-                strcpy(ln->left,K_ACTION_MAGIC);
+                strcpy(ln->left, K_ACTION_MAGIC);
                 deletedActions++;
                 ptr=&(*ptr)->next;
             }
@@ -214,18 +202,18 @@ void unaction_command(char *arg, struct session *ses)
         else
             ptr=&(*ptr)->next;
     }
-    if (!flag && ses->mesvar[1])    /* is it an error or not? */
+    if (!flag && ses->mesvar[MSG_ACTION])    /* is it an error or not? */
         tintin_printf(ses, "#No match(es) found for {%s}", left);
 }
 
 /*******************************/
 /* the #unpromptaction command */
 /*******************************/
-void unpromptaction_command(char *arg, struct session *ses)
+void unpromptaction_command(const char *arg, struct session *ses)
 {
     char left[BUFFER_SIZE];
-    struct listnode **ptr,*ln;
-    int flag;
+    struct listnode **ptr, *ln;
+    bool flag=false;
 
     arg = get_arg_in_braces(arg, left, 1);
     if (!*left)
@@ -233,21 +221,20 @@ void unpromptaction_command(char *arg, struct session *ses)
         tintin_eprintf(ses, "#Syntax: #unpromptaction <pattern>");
         return;
     }
-    flag = 0;
     ptr = &ses->prompts->next;
     while (*ptr)
     {
         ln=*ptr;
-        if (strcmp(ln->left,K_ACTION_MAGIC)&&match(left,ln->left))
+        if (strcmp(ln->left, K_ACTION_MAGIC)&&match(left, ln->left))
         {
-            flag=1;
-            if (ses->mesvar[1])
-                tintin_printf(ses,"#Ok. {%s} is no longer a promptaction.", ln->left);
+            flag=true;
+            if (ses->mesvar[MSG_ACTION])
+                tintin_printf(ses, "#Ok. {%s} is no longer a promptaction.", ln->left);
             SFREE(ln->left);
             if (inActions)
             {
                 ln->left=MALLOC(strlen(K_ACTION_MAGIC)+1);
-                strcpy(ln->left,K_ACTION_MAGIC);
+                strcpy(ln->left, K_ACTION_MAGIC);
                 deletedActions++;
                 ptr=&(*ptr)->next;
             }
@@ -262,7 +249,7 @@ void unpromptaction_command(char *arg, struct session *ses)
         else
             ptr=&(*ptr)->next;
     }
-    if (!flag && ses->mesvar[1])    /* is it an error or not? */
+    if (!flag && ses->mesvar[MSG_ACTION])    /* is it an error or not? */
         tintin_printf(ses, "#No match(es) found for {%s}", left);
 }
 
@@ -270,7 +257,7 @@ void unpromptaction_command(char *arg, struct session *ses)
 /* run through each of the commands on the right side of an alias/action  */
 /* expression, call substitute_text() for all commands but #alias/#action */
 /**************************************************************************/
-void prepare_actionalias(char *string, char *result, struct session *ses)
+void prepare_actionalias(const char *string, char *result, struct session *ses)
 {
     char arg[BUFFER_SIZE];
 
@@ -282,12 +269,13 @@ void prepare_actionalias(char *string, char *result, struct session *ses)
 /* copy the arg text into the result-space, but substitute the variables */
 /* %0..%9 with the real variables                                        */
 /*************************************************************************/
-void substitute_vars(char *arg, char *result)
+void substitute_vars(const char *arg, char *result)
 {
     int nest = 0;
     int numands, n;
-    char *ptr,*ARG=arg;
-    int valuelen,len=strlen(arg);
+    char *ptr;
+    const char *ARG=arg;
+    int valuelen, len=strlen(arg);
 
     if (!pvars)
     {
@@ -301,7 +289,7 @@ void substitute_vars(char *arg, char *result)
             numands = 1;        /* at least one */
             while (*(arg + numands) == '%')
                 numands++;
-            if (isdigit(*(arg + numands)) && numands == (nest + 1))
+            if (isadigit(*(arg + numands)) && numands == (nest + 1))
             {
                 n = *(arg + numands) - '0';
                 valuelen=strlen((*pvars)[n]);
@@ -310,8 +298,8 @@ void substitute_vars(char *arg, char *result)
                     len-=valuelen-numands-1;
                     if (!aborting)
                     {
-                        tintin_eprintf(0,"#ERROR: command+vars too long in {%s}.",ARG);
-                        aborting=1;
+                        tintin_eprintf(0, "#ERROR: command+vars too long in {%s}.", ARG);
+                        aborting=true;
                     }
                     goto novar1;
                 }
@@ -326,14 +314,14 @@ novar1:
                 arg += numands + 1;
                 result += numands + 1;
             }
-            in_alias=0; /* not a simple alias */
+            in_alias=false; /* not a simple alias */
         }
         if (*arg == '$')
         {               /* substitute variable */
             numands = 1;        /* at least one */
             while (*(arg + numands) == '$')
                 numands++;
-            if (isdigit(*(arg + numands)) && numands == (nest + 1))
+            if (isadigit(*(arg + numands)) && numands == (nest + 1))
             {
                 n = *(arg + numands) - '0';
                 valuelen=strlen((*pvars)[n]);
@@ -342,8 +330,8 @@ novar1:
                     len-=valuelen-numands-1;
                     if (!aborting)
                     {
-                        tintin_eprintf(0,"#ERROR: command+vars too long in {%s}.",ARG);
-                        aborting=1;
+                        tintin_eprintf(0, "#ERROR: command+vars too long in {%s}.", ARG);
+                        aborting=true;
                     }
                     goto novar2;
                 }
@@ -364,14 +352,14 @@ novar2:
                 arg += numands;
                 result += numands;
             }
-            in_alias=0; /* not a simple alias */
+            in_alias=false; /* not a simple alias */
         }
-        else if (*arg == DEFAULT_OPEN)
+        else if (*arg == BRACE_OPEN)
         {
             nest++;
             *result++ = *arg++;
         }
-        else if (*arg == DEFAULT_CLOSE)
+        else if (*arg == BRACE_CLOSE)
         {
             nest--;
             *result++ = *arg++;
@@ -394,33 +382,32 @@ novar2:
 }
 
 
-
 /**********************************************/
 /* check actions from a sessions against line */
 /**********************************************/
-void check_all_actions(char *line, struct session *ses)
+void check_all_actions(const char *line, struct session *ses)
 {
     struct listnode *ln;
-    pvars_t vars,*lastpvars;
+    pvars_t vars, *lastpvars;
 
     ln = ses->actions;
-    inActions=1;
+    inActions=true;
 
     while ((ln = ln->next))
     {
-        if (check_one_action(line, ln->left, &vars, 0, ses))
+        if (check_one_action(line, ln->left, &vars, false, ses))
         {
             lastpvars = pvars;
             pvars = &vars;
-            if (ses->mesvar[1] && activesession == ses)
+            if (ses->mesvar[MSG_ACTION] && activesession == ses)
             {
                 char buffer[BUFFER_SIZE];
 
                 prepare_actionalias(ln->right, buffer, ses);
-                tintin_printf(ses,"[ACTION: %s]", buffer);
+                tintin_printf(ses, "[ACTION: %s]", buffer);
             }
             debuglog(ses, "ACTION: {%s}->{%s}", line, ln->right);
-            parse_input(ln->right,1,ses);
+            parse_input(ln->right, true, ses);
             recursion=0;
             pvars = lastpvars;
             /*      return;*/    /* KB: we want ALL actions to be done */
@@ -428,28 +415,28 @@ void check_all_actions(char *line, struct session *ses)
     }
     if (deletedActions)
         zap_actions(ses);
-    inActions=0;
+    inActions=false;
 }
 
 
 /**********************************************/
 /* check actions from a sessions against line */
 /**********************************************/
-void check_all_promptactions(char *line, struct session *ses)
+void check_all_promptactions(const char *line, struct session *ses)
 {
     struct listnode *ln;
-    pvars_t vars,*lastpvars;
+    pvars_t vars, *lastpvars;
 
     ln = ses->prompts;
-    inActions=1;
+    inActions=true;
 
     while ((ln = ln->next))
     {
-        if (check_one_action(line, ln->left, &vars, 0, ses))
+        if (check_one_action(line, ln->left, &vars, false, ses))
         {
             lastpvars=pvars;
             pvars=&vars;
-            if (ses->mesvar[1] && activesession == ses)
+            if (ses->mesvar[MSG_ACTION] && activesession == ses)
             {
                 char buffer[BUFFER_SIZE];
 
@@ -457,7 +444,7 @@ void check_all_promptactions(char *line, struct session *ses)
                 tintin_printf(ses, "[PROMPT-ACTION: %s]", buffer);
             }
             debuglog(ses, "PROMPTACTION: {%s}->{%s}", line, ln->right);
-            parse_input(ln->right,1,ses);
+            parse_input(ln->right, true, ses);
             recursion=0;
             pvars=lastpvars;
             /*      return;*/    /* KB: we want ALL actions to be done */
@@ -465,19 +452,19 @@ void check_all_promptactions(char *line, struct session *ses)
     }
     if (deletedActions)
         zap_actions(ses);
-    inActions=0;
+    inActions=false;
 }
 
 
 /**********************/
 /* the #match command */
 /**********************/
-void match_command(char *arg, struct session *ses)
+void match_command(const char *arg, struct session *ses)
 {
-    pvars_t vars,*lastpvars;
+    pvars_t vars, *lastpvars;
     char left[BUFFER_SIZE], line[BUFFER_SIZE], right[BUFFER_SIZE],
          temp[BUFFER_SIZE];
-    int flag=0;
+    bool flag=false;
 
     arg=get_arg_in_braces(arg, left, 0);
     arg=get_arg_in_braces(arg, line, 0);
@@ -487,17 +474,17 @@ void match_command(char *arg, struct session *ses)
 
     if (!*left || !*right)
     {
-        tintin_eprintf(ses,"#ERROR: valid syntax is: #match <pattern> <line> <command> [#else ...]");
+        tintin_eprintf(ses, "#ERROR: valid syntax is: #match <pattern> <line> <command> [#else ...]");
         return;
     }
 
-    if (check_one_action(line, left, &vars, 0, ses))
+    if (check_one_action(line, left, &vars, false, ses))
     {
         lastpvars = pvars;
         pvars = &vars;
-        parse_input(right,1,ses);
+        parse_input(right, true, ses);
         pvars = lastpvars;
-        flag=1;
+        flag=true;
     }
     arg=get_arg_in_braces(arg, left, 0);
     if (*left == tintin_char)
@@ -506,7 +493,7 @@ void match_command(char *arg, struct session *ses)
         {
             get_arg_in_braces(arg, right, 1);
             if (!flag)
-                parse_input(right,1,ses);
+                parse_input(right, true, ses);
             return;
         }
         if (is_abrev(left + 1, "elif"))
@@ -517,14 +504,14 @@ void match_command(char *arg, struct session *ses)
         }
     }
     if (*left)
-        tintin_eprintf(ses,"#ERROR: cruft after #match: {%s}",left);
+        tintin_eprintf(ses, "#ERROR: cruft after #match: {%s}", left);
 }
 
 
 /*********************/
 /* the #match inline */
 /*********************/
-int match_inline(char *arg, struct session *ses)
+int match_inline(const char *arg, struct session *ses)
 {
     pvars_t vars;
     char left[BUFFER_SIZE], line[BUFFER_SIZE];
@@ -534,82 +521,74 @@ int match_inline(char *arg, struct session *ses)
 
     if (!*left)
     {
-        tintin_eprintf(ses,"#ERROR: valid syntax is: (#match <pattern> <line>)");
+        tintin_eprintf(ses, "#ERROR: valid syntax is: (#match <pattern> <line>)");
         return 0;
     }
 
-    return check_one_action(line, left, &vars, 0, ses);
+    return check_one_action(line, left, &vars, false, ses);
 }
 
 
-static int match_a_string(char *line, char *mask)
+static int match_a_string(const char *line, const char *mask)
 {
-    char *lptr, *mptr;
+    const char *lptr, *mptr;
 
     lptr = line;
     mptr = mask;
     while (*lptr && *mptr && !(*mptr == '%' && isadigit(*(mptr + 1))))
         if (*lptr++ != *mptr++)
             return -1;
-    if (!*mptr || (*mptr == '%' && isdigit(*(mptr + 1))))
+    if (!*mptr || (*mptr == '%' && isadigit(*(mptr + 1))))
         return (int)(lptr - line);
     return -1;
 }
 
-int check_one_action(char *line, char *action, pvars_t *vars, int inside, struct session *ses)
+bool check_one_action(const char *line, const char *action, pvars_t *vars, bool inside, struct session *ses)
 {
-    int i;
+    if (!check_a_action(line, action, inside, ses))
+        return false;
 
-    if (check_a_action(line, action, inside, ses))
+    for (int i = 0; i < 10; i++)
     {
-        for (i = 0; i < 10; i++)
+        if (var_len[i] != -1)
         {
-            if (var_len[i] != -1)
-            {
-                strncpy((*vars)[i], var_ptr[i], var_len[i]);
-                *((*vars)[i] + var_len[i]) = '\0';
-            }
-            else
-                (*vars)[i][0]=0;
+            strncpy((*vars)[i], var_ptr[i], var_len[i]);
+            *((*vars)[i] + var_len[i]) = '\0';
         }
-        return TRUE;
+        else
+            (*vars)[i][0]=0;
     }
-    else
-        return FALSE;
+    return true;
 }
 
 /******************************************************************/
 /* check if a text triggers an action and fill into the variables */
-/* return TRUE if triggered                                       */
+/* return true if triggered                                       */
 /******************************************************************/
-static int check_a_action(char *line, char *action, int inside, struct session *ses)
+static bool check_a_action(const char *line, const char *action, bool inside, struct session *ses)
 {
     char result[BUFFER_SIZE];
-    char *temp2, *tptr, *lptr, *lptr2;
-    int i, flag_anchor, len;
+    char *temp2, *tptr;
+    const char *lptr, *lptr2;
+    int len;
+    bool flag_anchor = false;
 
-    for (i = 0; i < 10; i++)
+    for (int i = 0; i < 10; i++)
         var_len[i] = -1;
-    flag_anchor = FALSE;
     lptr = line;
     substitute_myvars(action, result, ses);
     tptr = result;
     if (*tptr == '^')
     {
         if (inside)
-            return 0;
+            return false;
         tptr++;
-        flag_anchor = TRUE;
-        /* CHANGED to fix a bug with #action {^%0 foo}
-         * Thanks to Spencer Sun for the bug report (AND fix!)
-         if (*tptr!=*line)
-         return FALSE;
-         */
+        flag_anchor = true;
     }
     if (flag_anchor)
     {
         if ((len = match_a_string(lptr, tptr)) == -1)
-            return FALSE;
+            return false;
         match_start=lptr;
         lptr += len;
         tptr += len;
@@ -629,7 +608,7 @@ static int check_a_action(char *line, char *action, int inside, struct session *
             tptr += len;
         }
         else
-            return FALSE;
+            return false;
     }
     while (*lptr && *tptr)
     {
@@ -639,7 +618,7 @@ static int check_a_action(char *line, char *action, int inside, struct session *
             var_len[*(tptr + 1) - 48] = strlen(lptr);
             var_ptr[*(tptr + 1) - 48] = lptr;
             match_end=""; /* NOTE: to use (match_end-line) change this line */
-            return TRUE;
+            return true;
         }
         lptr2 = lptr;
         len = -1;
@@ -658,23 +637,20 @@ static int check_a_action(char *line, char *action, int inside, struct session *
             tptr = temp2 + len;
         }
         else
-            return FALSE;
+            return false;
     }
-    if ((*tptr=='%')&&isdigit(*(tptr+1)))
+    if ((*tptr=='%')&&isadigit(*(tptr+1)))
     {
         var_len[*(tptr+1)-48]=0;
         var_ptr[*(tptr+1)-48]=lptr;
         tptr+=2;
-    };
+    }
     match_end=lptr;
-    if (*tptr)
-        return FALSE;
-    else
-        return TRUE;
+    return !*tptr;
 }
 
 
-void doactions_command(char *arg, struct session *ses)
+void doactions_command(const char *arg, struct session *ses)
 {
     char line[BUFFER_SIZE];
 
@@ -685,7 +661,7 @@ void doactions_command(char *arg, struct session *ses)
 }
 
 
-void dopromptactions_command(char *arg, struct session *ses)
+void dopromptactions_command(const char *arg, struct session *ses)
 {
     char line[BUFFER_SIZE];
 
