@@ -11,6 +11,7 @@
 #include "protos/colors.h"
 #include "protos/files.h"
 #include "protos/glob.h"
+#include "protos/globals.h"
 #include "protos/hash.h"
 #include "protos/highlight.h"
 #include "protos/history.h"
@@ -20,6 +21,7 @@
 #include "protos/misc.h"
 #include "protos/net.h"
 #include "protos/parse.h"
+#include "protos/prof.h"
 #include "protos/session.h"
 #include "protos/substitute.h"
 #include "protos/ticks.h"
@@ -30,74 +32,23 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
-#include "ui.h"
 
 #ifndef BADSIG
-#define BADSIG (void (*)())-1
+#define BADSIG (void (*)(int))-1
 #endif
 
 typedef void (*sighandler_t)(int);
 
-extern void end_command(char *arg, struct session *ses);
+extern void end_command(const char *arg, struct session *ses);
 
-static void echo_input(char *txt);
-
-/*************** globals ******************/
-int term_echoing = TRUE;
-int keypad= DEFAULT_KEYPAD;
-int retain= DEFAULT_RETAIN;
-int alnum = 0;
-int acnum = 0;
-int subnum = 0;
-int varnum = 0;
-int hinum = 0;
-int routnum = 0;
-int pdnum = 0;
-int antisubnum = 0;
-int bindnum = 0;
-int hooknum = 0;
-int gotpassword=0;
-int got_more_kludge=0;
-int hist_num;
-int need_resize=0;
-extern int LINES,COLS;
-extern int tty,xterm;
-char *tintin_exec;
-struct session *lastdraft;
-int aborting=0;
-int eofinput=0;
-int any_closed=0;
-extern int recursion;
-char *_; /* incoming line being processed */
-extern int o_lastcolor;
-int real_quiet=0; /* if set, #verbose 0 will be really quiet */
-char *history[HISTORY_SIZE];
-struct session *sessionlist, *activesession, *nullsession;
-pvars_t *pvars; /* the %0, %1, %2,....%9 variables */
-char tintin_char = DEFAULT_TINTIN_CHAR;
-char verbatim_char = DEFAULT_VERBATIM_CHAR;
-char prev_command[BUFFER_SIZE];
+static void echo_input(const char *txt);
+static bool eofinput=false;
+static char prev_command[BUFFER_SIZE];
 static void tintin(void);
 static void read_mud(struct session *ses);
-static void do_one_line(char *line,int nl,struct session *ses);
-static void snoop(char *buffer, struct session *ses);
-char status[BUFFER_SIZE];
-
-/************ externs *************/
-extern char done_input[BUFFER_SIZE];
-
-extern time_t time0;
-extern int utime0;
-
+static void do_one_line(char *line, int nl, struct session *ses);
+static void snoop(const char *buffer, struct session *ses);
 static void myquitsig(int);
-extern struct completenode *complete_head;
-#ifdef PROFILING
-extern char *prof_area;
-extern time_t kbd_lag, mud_lag;
-extern int kbd_cnt, mud_cnt;
-extern void setup_prof();
-#endif
-extern int ui_sep_input;
 
 static void tstphandler(int sig)
 {
@@ -108,7 +59,7 @@ static void tstphandler(int sig)
 
 static void sigchild(void)
 {
-    while (waitpid(-1,0,WNOHANG)>0);
+    while (waitpid(-1, 0, WNOHANG)>0);
 }
 
 static void sigcont(void)
@@ -122,7 +73,7 @@ static void sigsegv(void)
     if (ui_own_output)
         user_done();
     fflush(0);
-/*  write(2,"Segmentation fault.\n",20);*/
+/*  write(2, "Segmentation fault.\n", 20);*/
     signal(SIGSEGV, SIG_DFL);
     raise(SIGSEGV);
 /*  exit(SIGSEGV);*/
@@ -133,7 +84,7 @@ static void sigfpe(void)
     if (ui_own_output)
         user_done();
     fflush(0);
-/*  write(2,"Floating point exception.\n",26);*/
+/*  write(2, "Floating point exception.\n", 26);*/
     signal(SIGFPE, SIG_DFL);
     raise(SIGFPE);
 /*  exit(SIGFPE);*/
@@ -148,28 +99,28 @@ static void sighup(void)
 
 static void sigwinch(void)
 {
-    need_resize=1;
+    need_resize=true;
 }
 
 
-static int new_news(void)
+static bool new_news(void)
 {
     struct stat KBtin, news;
 
     if (stat(tintin_exec, &KBtin))
-        return 0;       /* can't stat the executable??? */
+        return false;       /* can't stat the executable??? */
     if (stat(NEWS_FILE, &news))
 #ifdef DATA_PATH
         if (stat(DATA_PATH "/" NEWS_FILE, &news))
 #endif
-            return 0;       /* either no NEWS file, or can't stat it */
+            return false;       /* either no NEWS file, or can't stat it */
     return (news.st_ctime>=news.st_atime)||(KBtin.st_ctime+10>news.st_atime);
 }
 
 /************************/
 /* the #suspend command */
 /************************/
-void suspend_command(char *arg, struct session *ses)
+void suspend_command(const char *arg, struct session *ses)
 {
     tstphandler(SIGTSTP);
 }
@@ -189,29 +140,29 @@ static void setup_signals(void)
     if (signal(SIGHUP, (sighandler_t)sighup) == BADSIG)
         syserr("signal SIGHUP");
     act.sa_handler=(sighandler_t)tstphandler;
-    if (sigaction(SIGTSTP,&act,0))
+    if (sigaction(SIGTSTP, &act, 0))
         syserr("sigaction SIGTSTP");
 
-    if (ui_own_output && ui_tty)
+    if (ui_own_output)
     {
         act.sa_handler=(sighandler_t)sigcont;
-        if (sigaction(SIGCONT,&act,0))
+        if (sigaction(SIGCONT, &act, 0))
             syserr("sigaction SIGCONT");
         act.sa_handler=(sighandler_t)sigwinch;
-        if (sigaction(SIGWINCH,&act,0))
+        if (sigaction(SIGWINCH, &act, 0))
             syserr("sigaction SIGWINCH");
     }
 
     if (ui_own_output)
     {
-        if (signal(SIGSEGV,(sighandler_t)sigsegv) == BADSIG)
+        if (signal(SIGSEGV, (sighandler_t)sigsegv) == BADSIG)
             syserr("signal SIGSEGV");
-        if (signal(SIGFPE,(sighandler_t)sigfpe) == BADSIG)
+        if (signal(SIGFPE, (sighandler_t)sigfpe) == BADSIG)
             syserr("signal SIGFPE");
     }
 
     act.sa_handler=(sighandler_t)sigchild;
-    if (sigaction(SIGCHLD,&act,0))
+    if (sigaction(SIGCHLD, &act, 0))
         syserr("sigaction SIGCHLD");
     if (signal(SIGPIPE, SIG_IGN) == BADSIG)
         syserr("signal SIGPIPE");
@@ -224,7 +175,7 @@ static void setup_ulimit(void)
 {
     struct rlimit rlim;
 
-    if (getrlimit(RLIMIT_STACK,&rlim))
+    if (getrlimit(RLIMIT_STACK, &rlim))
         return;
     if ((unsigned int)rlim.rlim_cur>=STACK_LIMIT)
         return;
@@ -234,12 +185,11 @@ static void setup_ulimit(void)
         rlim.rlim_cur=rlim.rlim_max;
     else
         rlim.rlim_cur=STACK_LIMIT;
-    setrlimit(RLIMIT_STACK,&rlim);
+    setrlimit(RLIMIT_STACK, &rlim);
 }
 
 static void init_nullses(void)
 {
-    int i;
     struct timeval tv;
 
     gettimeofday(&tv, 0);
@@ -249,11 +199,11 @@ static void init_nullses(void)
     nullsession=TALLOC(struct session);
     nullsession->name=mystrdup("main");
     nullsession->address=0;
-    nullsession->tickstatus = FALSE;
+    nullsession->tickstatus = false;
     nullsession->tick_size = DEFAULT_TICK_SIZE;
     nullsession->pretick = DEFAULT_PRETICK;
     nullsession->time0 = 0;
-    nullsession->snoopstatus = TRUE;
+    nullsession->snoopstatus = true;
     nullsession->logfile = 0;
     nullsession->logname = 0;
     nullsession->logtype = DEFAULT_LOGTYPE;
@@ -265,7 +215,7 @@ static void init_nullses(void)
     nullsession->speedwalk = DEFAULT_SPEEDWALK;
     nullsession->togglesubs = DEFAULT_TOGGLESUBS;
     nullsession->presub = DEFAULT_PRESUB;
-    nullsession->verbatim = 0;
+    nullsession->verbatim = false;
     nullsession->ignore = DEFAULT_IGNORE;
     nullsession->partial_line_marker = mystrdup(DEFAULT_PARTIAL_LINE_MARKER);
     nullsession->aliases = init_hash();
@@ -276,16 +226,16 @@ static void init_nullses(void)
     nullsession->highs = init_list();
     nullsession->pathdirs = init_hash();
     nullsession->socket = 0;
-    nullsession->issocket = 0;
-    nullsession->naws = 0;
+    nullsession->issocket = false;
+    nullsession->naws = false;
 #ifdef HAVE_ZLIB
-    nullsession->can_mccp = 0;
+    nullsession->can_mccp = false;
     nullsession->mccp = 0;
-    nullsession->mccp_more = 0;
+    nullsession->mccp_more = false;
 #endif
     nullsession->last_term_type=0;
     nullsession->server_echo = 0;
-    nullsession->nagle = 0;
+    nullsession->nagle = false;
     nullsession->antisubs = init_list();
     nullsession->binds = init_hash();
     nullsession->next = 0;
@@ -293,40 +243,40 @@ static void init_nullses(void)
         nullsession->server_idle_since=time(0);
     nullsession->debuglogfile=0;
     nullsession->debuglogname=0;
-    for (i=0;i<HISTORY_SIZE;i++)
+    for (int i=0;i<HISTORY_SIZE;i++)
         history[i]=0;
-    for (i=0;i<MAX_LOCATIONS;i++)
+    for (int i=0;i<MAX_LOCATIONS;i++)
     {
         nullsession->routes[i]=0;
         nullsession->locations[i]=0;
     }
-    for (i=0;i<NHOOKS;i++)
+    for (int i=0;i<NHOOKS;i++)
         nullsession->hooks[i]=0;
     nullsession->path = init_list();
     nullsession->no_return = 0;
     nullsession->path_length = 0;
     nullsession->last_line[0] = 0;
     nullsession->events = NULL;
-    nullsession->verbose=0;
-    nullsession->closing=0;
+    nullsession->verbose=false;
+    nullsession->closing=false;
     sessionlist = nullsession;
     activesession = nullsession;
     pvars=0;
 
-    nullsession->mesvar[0] = DEFAULT_ALIAS_MESS;
-    nullsession->mesvar[1] = DEFAULT_ACTION_MESS;
-    nullsession->mesvar[2] = DEFAULT_SUB_MESS;
-    nullsession->mesvar[3] = DEFAULT_EVENT_MESS;
-    nullsession->mesvar[4] = DEFAULT_HIGHLIGHT_MESS;
-    nullsession->mesvar[5] = DEFAULT_VARIABLE_MESS;
-    nullsession->mesvar[6] = DEFAULT_ROUTE_MESS;
-    nullsession->mesvar[7] = DEFAULT_GOTO_MESS;
-    nullsession->mesvar[8] = DEFAULT_BIND_MESS;
-    nullsession->mesvar[9] = DEFAULT_SYSTEM_MESS;
-    nullsession->mesvar[10]= DEFAULT_PATH_MESS;
-    nullsession->mesvar[11]= DEFAULT_ERROR_MESS;
-    nullsession->mesvar[12]= DEFAULT_HOOK_MESS;
-    nullsession->mesvar[13]= DEFAULT_LOG_MESS;
+    nullsession->mesvar[MSG_ALIAS] = DEFAULT_ALIAS_MESS;
+    nullsession->mesvar[MSG_ACTION] = DEFAULT_ACTION_MESS;
+    nullsession->mesvar[MSG_SUBSTITUTE] = DEFAULT_SUB_MESS;
+    nullsession->mesvar[MSG_EVENT] = DEFAULT_EVENT_MESS;
+    nullsession->mesvar[MSG_HIGHLIGHT] = DEFAULT_HIGHLIGHT_MESS;
+    nullsession->mesvar[MSG_VARIABLE] = DEFAULT_VARIABLE_MESS;
+    nullsession->mesvar[MSG_ROUTE] = DEFAULT_ROUTE_MESS;
+    nullsession->mesvar[MSG_GOTO] = DEFAULT_GOTO_MESS;
+    nullsession->mesvar[MSG_BIND] = DEFAULT_BIND_MESS;
+    nullsession->mesvar[MSG_SYSTEM] = DEFAULT_SYSTEM_MESS;
+    nullsession->mesvar[MSG_PATH]= DEFAULT_PATH_MESS;
+    nullsession->mesvar[MSG_ERROR]= DEFAULT_ERROR_MESS;
+    nullsession->mesvar[MSG_HOOK]= DEFAULT_HOOK_MESS;
+    nullsession->mesvar[MSG_LOG]= DEFAULT_LOG_MESS;
     nullsession->charset=mystrdup(DEFAULT_CHARSET);
     nullsession->logcharset=logcs_is_special(DEFAULT_LOGCHARSET) ?
                               DEFAULT_LOGCHARSET : mystrdup(DEFAULT_LOGCHARSET);
@@ -339,7 +289,7 @@ static void init_nullses(void)
 #endif
 }
 
-static void opterror(char *msg, ...)
+static void opterror(const char *msg, ...)
 {
     va_list ap;
 
@@ -354,45 +304,44 @@ static struct listnode *options;
 
 static void parse_options(int argc, char **argv)
 {
-    int noargs=0;
-    int arg;
+    bool noargs=false;
 
     options=init_list();
 
-    for (arg=1;arg<argc;arg++)
+    for (int arg=1;arg<argc;arg++)
     {
         if (*argv[arg]=='-' && !noargs)
         {
-            if (!strcmp(argv[arg],"--"))
-                noargs=1;
-            else if (!strcmp(argv[arg],"--version")) /* make autotest happy */
+            if (!strcmp(argv[arg], "--"))
+                noargs=true;
+            else if (!strcmp(argv[arg], "--version")) /* make autotest happy */
             {
                 printf("KBtin version "VERSION"\n");
                 exit(0);
             }
-            else if (!strcmp(argv[arg],"-v"))
+            else if (!strcmp(argv[arg], "-v"))
                 addnode_list(options, "#verbose 1", 0, 0);
-            else if (!strcmp(argv[arg],"-q"))
+            else if (!strcmp(argv[arg], "-q"))
                 addnode_list(options, "#verbose 0", 0, 0);
-            else if (!strcmp(argv[arg],"-p"))
+            else if (!strcmp(argv[arg], "-p"))
                 user_setdriver(0);
-            else if (!strcmp(argv[arg],"-i"))
+            else if (!strcmp(argv[arg], "-i"))
                 user_setdriver(1);
-            else if (!strcmp(argv[arg],"-c"))
+            else if (!strcmp(argv[arg], "-c"))
             {
                 if (++arg==argc)
                     opterror("Invalid option: bare -c");
                 else
                     addnode_list(options, "c", argv[arg], 0);
             }
-            else if (!strcmp(argv[arg],"-r"))
+            else if (!strcmp(argv[arg], "-r"))
             {
                 if (++arg==argc)
                     opterror("Invalid option: bare -r");
                 else
                     addnode_list(options, "r", argv[arg], 0);
             }
-            else if (!strcasecmp(argv[arg],"-s"))
+            else if (!strcasecmp(argv[arg], "-s"))
             {
                 if (++arg==argc)
                     opterror("Invalid option: bare %s", argv[arg]);
@@ -402,7 +351,7 @@ static void parse_options(int argc, char **argv)
                     addnode_list(options, argv[arg-2]+1, argv[arg-1], argv[arg]);
             }
             else
-                opterror("Invalid option: {%s}",argv[arg]);
+                opterror("Invalid option: {%s}", argv[arg]);
         }
         else
             addnode_list(options, " ", argv[arg], 0);
@@ -411,50 +360,50 @@ static void parse_options(int argc, char **argv)
         addnode_list(options, "-", 0, 0);
 }
 
-static void apply_options()
+static void apply_options(void)
 {
-    struct listnode *opt;
-    char homepath[BUFFER_SIZE], temp[BUFFER_SIZE], sname[BUFFER_SIZE], *strptr;
+    char temp[BUFFER_SIZE], sname[BUFFER_SIZE];
     char ustr[BUFFER_SIZE];
+    const char *home;
     FILE *f;
-# define DO_INPUT(str,iv) local_to_utf8(ustr,str,BUFFER_SIZE,0);\
-                          activesession=parse_input(str,iv,activesession);
+# define DO_INPUT(str,iv) local_to_utf8(ustr, str, BUFFER_SIZE, 0);\
+                          activesession=parse_input(str, iv, activesession);
 
-    for (opt=options->next; opt; opt=opt->next)
+    for (struct listnode *opt=options->next; opt; opt=opt->next)
     {
         switch (*opt->left)
         {
         case '#':
             *opt->left=tintin_char;
-            activesession=parse_input(opt->left,1,activesession);
+            activesession=parse_input(opt->left, true, activesession);
             break;
         case 'c':
-            DO_INPUT(opt->right, 0);
+            DO_INPUT(opt->right, false);
             break;
         case 'r':
             set_magic_hook(activesession);
-            make_name(sname, opt->right, 1);
+            make_name(sname, opt->right);
             snprintf(temp, BUFFER_SIZE,
                 "%crun %s {%s}", tintin_char, sname, opt->right);
-            DO_INPUT(temp, 1);
+            DO_INPUT(temp, true);
             break;
         case 's':
             set_magic_hook(activesession);
-            make_name(sname, opt->right, 1);
+            make_name(sname, opt->right);
             snprintf(temp, BUFFER_SIZE,
                 "%cses %s {%s %s}", tintin_char, sname, opt->right, opt->pr);
-            DO_INPUT(temp, 1);
+            DO_INPUT(temp, true);
             break;
         case 'S':
             set_magic_hook(activesession);
-            make_name(sname, opt->right, 1);
+            make_name(sname, opt->right);
             snprintf(temp, BUFFER_SIZE,
                 "%csslses %s {%s %s}", tintin_char, sname, opt->right, opt->pr);
-            DO_INPUT(temp, 1);
+            DO_INPUT(temp, true);
             break;
         case ' ':
             local_to_utf8(ustr, opt->right, BUFFER_SIZE, 0);
-            if ((f=fopen(opt->right,"r")))
+            if ((f=fopen(opt->right, "r")))
             {
                 if (activesession->verbose || !real_quiet)
                     tintin_printf(0, "#READING {%s}", ustr);
@@ -464,31 +413,25 @@ static void apply_options()
                 tintin_eprintf(0, "#FILE NOT FOUND: {%s}", ustr);
             break;
         case '-':
-            *homepath = '\0';
             if (!strcmp(DEFAULT_FILE_DIR, "HOME"))
-                if ((strptr = (char *)getenv("HOME")))
-                    strcpy(homepath, strptr);
+                if ((home = getenv("HOME")))
+                    strcpy(temp, home);
                 else
-                    *homepath = '\0';
+                    *temp = '\0';
             else
-                strcpy(homepath, DEFAULT_FILE_DIR);
+                strcpy(temp, DEFAULT_FILE_DIR);
 
-            strcpy(temp, homepath);
             strcat(temp, "/.tintinrc");
             local_to_utf8(ustr, temp, BUFFER_SIZE, 0);
-            if ((f=fopen(temp,"r")))
+            if ((f=fopen(temp, "r")))
                 activesession = do_read(f, ustr, activesession);
-            else
+            else if ((home = getenv("HOME")))
             {
-                if ((strptr = (char *)getenv("HOME")))
-                {
-                    strcpy(homepath, strptr);
-                    strcpy(temp, homepath);
-                    strcat(temp, "/.tintinrc");
-                    local_to_utf8(ustr, temp, BUFFER_SIZE, 0);
-                    if ((f=fopen(temp,"r")))
-                        activesession = do_read(f, ustr, activesession);
-                }
+                strcpy(temp, home);
+                strcat(temp, "/.tintinrc");
+                local_to_utf8(ustr, temp, BUFFER_SIZE, 0);
+                if ((f=fopen(temp, "r")))
+                    activesession = do_read(f, ustr, activesession);
             }
         }
     }
@@ -510,7 +453,7 @@ int main(int argc, char **argv)
     init_bind();
     hist_num=-1;
     init_parse();
-    strcpy(status,EMPTY_LINE);
+    strcpy(status, EMPTY_LINE);
     user_init();
     /*  read_complete();            no tab-completion */
     ses = NULL;
@@ -526,23 +469,23 @@ every time.  It is not GNU bc or something similar, we don't want half
 a screenful of all-uppercase (cAPS kEY IS STUCK AGAIN?) text that no one
 ever wants to read -- that is what docs are for.
 */
-        tintin_printf(0,"~2~##########################################################");
-        tintin_printf(0, "#~7~                ~12~K B ~3~t i n~7~     v %-23s ~2~#", VERSION);
-        tintin_printf(0,"#                                                        #");
-        tintin_printf(0,"#~7~ current developer: ~9~Adam Borowski (~9~kilobyte@angband.pl~7~) ~2~#");
-        tintin_printf(0,"#                                                        #");
-        tintin_printf(0,"#~7~ based on ~12~tintin++~7~ v 2.1.9 by Peter Unold, Bill Reiss,  ~2~#");
-        tintin_printf(0,"#~7~   David A. Wagner, Joann Ellsworth, Jeremy C. Jack,    ~2~#");
-        tintin_printf(0,"#~7~          Ulan@GrimneMUD and Jakub Narębski             ~2~#");
-        tintin_printf(0,"##########################################################~7~");
-        tintin_printf(0,"~15~#session <name> <host> <port> ~7~to connect to a remote server");
-        tintin_printf(0,"                              ~8~#ses t2t t2tmud.org 9999");
-        tintin_printf(0,"~15~#run <name> <command>         ~7~to run a local command");
-        tintin_printf(0,"                              ~8~#run advent adventure");
-        tintin_printf(0,"                              ~8~#run sql mysqlclient");
-        tintin_printf(0,"~15~#help                         ~7~to get the help index");
+        tintin_printf(0, "~2~##########################################################");
+        tintin_printf(0, "#~7~               ~12~K B ~3~t i n~7~    v %-25s ~2~#", VERSION);
+        tintin_printf(0, "#                                                        #");
+        tintin_printf(0, "#~7~ current developer: ~9~Adam Borowski (~9~kilobyte@angband.pl~7~) ~2~#");
+        tintin_printf(0, "#                                                        #");
+        tintin_printf(0, "#~7~ based on ~12~tintin++~7~ v 2.1.9 by Peter Unold, Bill Reiss,  ~2~#");
+        tintin_printf(0, "#~7~   David A. Wagner, Joann Ellsworth, Jeremy C. Jack,    ~2~#");
+        tintin_printf(0, "#~7~          Ulan@GrimneMUD and Jakub Narębski             ~2~#");
+        tintin_printf(0, "##########################################################~7~");
+        tintin_printf(0, "~15~#session <name> <host> <port> ~7~to connect to a remote server");
+        tintin_printf(0, "                              ~8~#ses t2t t2tmud.org 9999");
+        tintin_printf(0, "~15~#run <name> <command>         ~7~to run a local command");
+        tintin_printf(0, "                              ~8~#run advent adventure");
+        tintin_printf(0, "                              ~8~#run sql mysql");
+        tintin_printf(0, "~15~#help                         ~7~to get the help index");
         if (new_news())
-            tintin_printf(ses,"Check #news now!");
+            tintin_printf(ses, "Check #news now!");
     }
     user_mark_greeting();
 
@@ -565,13 +508,12 @@ ever wants to read -- that is what docs are for.
 /******************************************************/
 static int check_events(void)
 {
-    struct session *sp;
     int tick_time = 0, curr_time, tt;
 
     curr_time = time(NULL);
 restart:
-    any_closed=0;
-    for (sp = sessionlist; sp; sp = sp->next)
+    any_closed=false;
+    for (struct session *sp = sessionlist; sp; sp = sp->next)
     {
         tt = check_event(curr_time, sp);
         if (any_closed)
@@ -592,7 +534,6 @@ restart:
 static void tintin(void)
 {
     int i, result, maxfd;
-    struct session *sesptr;
     struct timeval tv;
     fd_set readfdmask;
 #ifdef XTERM_TITLE
@@ -605,7 +546,7 @@ static void tintin(void)
 
     memset(&instate, 0, sizeof(instate));
 
-    while (TRUE)
+    for (;;)
     {
 #ifdef XTERM_TITLE
         if (ui_own_output && activesession!=lastsession)
@@ -625,18 +566,17 @@ static void tintin(void)
         FD_ZERO(&readfdmask);
         if (!eofinput)
             FD_SET(0, &readfdmask);
-        else
-            if (activesession==nullsession)
-                end_command(0, activesession);
-        for (sesptr = sessionlist; sesptr; sesptr = sesptr->next)
+        else if (activesession==nullsession)
+            end_command(0, activesession);
+        for (struct session *ses = sessionlist; ses; ses = ses->next)
         {
-            if (sesptr==nullsession)
+            if (ses==nullsession)
                 continue;
-            if (sesptr->nagle)
-                flush_socket(sesptr);
-            FD_SET(sesptr->socket, &readfdmask);
-            if (sesptr->socket>maxfd)
-                maxfd=sesptr->socket;
+            if (ses->nagle)
+                flush_socket(ses);
+            FD_SET(ses->socket, &readfdmask);
+            if (ses->socket>maxfd)
+                maxfd=ses->socket;
         }
         result = select(maxfd+1, &readfdmask, 0, 0, &tv);
 
@@ -664,7 +604,7 @@ static void tintin(void)
             if (result==-1)
                 myquitsig(0);
             if (result==0 && !isatty(0))
-                eofinput=1;
+                eofinput=true;
             inbuf+=result;
 
             i=0;
@@ -708,33 +648,33 @@ static void tintin(void)
                     }
                     if (*done_input)
                         strcpy(prev_command, done_input);
-                    aborting=0;
-                    activesession = parse_input(done_input,0,activesession);
+                    aborting=false;
+                    activesession = parse_input(done_input, false, activesession);
                     recursion=0;
                 }
             }
             inbuf=0;
         partial:
-            PROFEND(kbd_lag,kbd_cnt);
+            PROFEND(kbd_lag, kbd_cnt);
             PROFPOP;
         }
-        for (sesptr = sessionlist; sesptr; sesptr = sesptr->next)
+        for (struct session *ses = sessionlist; ses; ses = ses->next)
         {
-            if (sesptr->socket && FD_ISSET(sesptr->socket,&readfdmask))
+            if (ses->socket && FD_ISSET(ses->socket, &readfdmask))
             {
-                aborting=0;
-                any_closed=0;
+                aborting=false;
+                any_closed=false;
                 do
                 {
-                    read_mud(sesptr);
+                    read_mud(ses);
                     if (any_closed)
                     {
-                        any_closed=0;
+                        any_closed=false;
                         goto after_read;
                         /* The remaining sessions will be done after select() */
                     }
 #ifdef HAVE_ZLIB
-                } while (sesptr->mccp_more);
+                } while (ses->mccp_more);
 #else
                 } while (0);
 #endif
@@ -746,7 +686,7 @@ static void tintin(void)
         {
             gotpassword= 2-activesession->server_echo;
             if (!gotpassword)
-                got_more_kludge=0;
+                got_more_kludge=false;
             user_passwd(gotpassword && !got_more_kludge);
             term_echoing=!gotpassword;
         }
@@ -761,7 +701,7 @@ static void read_mud(struct session *ses)
 {
     char buffer[BUFFER_SIZE], linebuffer[BUFFER_SIZE], *cpsource, *cpdest;
     char temp[BUFFER_SIZE];
-    int didget, n, count;
+    int didget, count;
 
     PROFSTART;
     if ((didget = read_buffer_mud(buffer, ses))==-1)
@@ -771,11 +711,8 @@ static void read_mud(struct session *ses)
             activesession = newactive_session();
         return;
     }
-    else
-    {
-        if (!didget)
-            return; /* possible if only telnet protocol data was received */
-    }
+    else if (!didget)
+        return; /* possible if only telnet protocol data was received */
     if (ses->logfile)
     {
         if (ses->logtype)
@@ -784,21 +721,18 @@ static void read_mud(struct session *ses)
 
             if (ses->halfcr_log)
             {
-                ses->halfcr_log=0;
+                ses->halfcr_log=false;
                 if (buffer[0]!='\n')
                     temp[count++]='\r';
             }
 
-            for (n = 0; n < didget; n++)
+            for (int n = 0; n < didget; n++)
                 if (buffer[n] != '\r')
                     temp[count++] = buffer[n];
-                else
-                {
-                    if (n+1==didget)
-                        ses->halfcr_log=1;
-                    else if (buffer[n+1]!='\n')
-                        temp[count++]='\r';
-                }
+                else if (n+1==didget)
+                    ses->halfcr_log=true;
+                else if (buffer[n+1]!='\n')
+                    temp[count++]='\r';
             temp[count]=0;      /* didget<BUFFER_SIZE, so no overflow */
             write_log(ses, temp, count);
         }
@@ -811,11 +745,11 @@ static void read_mud(struct session *ses)
 
     cpsource = buffer;
     strcpy(linebuffer, ses->last_line);
-    cpdest = strchr(linebuffer,'\0');
+    cpdest = strchr(linebuffer, '\0');
 
     if (ses->halfcr_in)
     {
-        ses->halfcr_in=0;
+        ses->halfcr_in=false;
         goto halfcr;
     }
     while (*cpsource)
@@ -823,7 +757,7 @@ static void read_mud(struct session *ses)
         if (*cpsource == '\n')
         {
             *cpdest = '\0';
-            do_one_line(linebuffer,1,ses);
+            do_one_line(linebuffer, 1, ses);
             ses->lastintitle=0;
 
             cpsource++;
@@ -837,13 +771,13 @@ static void read_mud(struct session *ses)
                 continue;
             if (!*cpsource)
             {
-                ses->halfcr_in=1;
+                ses->halfcr_in=true;
                 break;
             }
             *cpdest=0;
             if (cpdest!=linebuffer)
             {
-                do_one_line(linebuffer,0,ses);
+                do_one_line(linebuffer, 0, ses);
                 ses->lastintitle=0;
             }
             cpdest=linebuffer;
@@ -854,29 +788,29 @@ static void read_mud(struct session *ses)
     if (cpdest-linebuffer>INPUT_CHUNK) /* let's split too long lines */
     {
         *cpdest=0;
-        do_one_line(linebuffer,1,ses);
+        do_one_line(linebuffer, 1, ses);
         ses->lastintitle=0;
         cpdest=linebuffer;
     }
     *cpdest = '\0';
-    strcpy(ses->last_line,linebuffer);
+    strcpy(ses->last_line, linebuffer);
     if (!ses->more_coming)
         if (cpdest!=linebuffer)
-            do_one_line(linebuffer,0,ses);
+            do_one_line(linebuffer, 0, ses);
     PROFEND(mud_lag, mud_cnt);
 }
 
 /**********************************************************/
 /* do all of the functions to one line of buffer          */
 /**********************************************************/
-static void do_one_line(char *line,int nl,struct session *ses)
+static void do_one_line(char *line, int nl, struct session *ses)
 {
-    int isnb;
+    bool isnb;
     char ubuf[BUFFER_SIZE];
-    struct timeval t1,t2;
+    struct timeval t1, t2;
 
     if (nl)
-        gettimeofday(&t1,0);
+        gettimeofday(&t1, 0);
     PROFPUSH("conv: remote->utf8");
     convert(&ses->c_io, ubuf, line, -1);
 # define line ubuf
@@ -884,26 +818,26 @@ static void do_one_line(char *line,int nl,struct session *ses)
     switch (ses->server_echo)
     {
     case 0:
-        if ((match(PROMPT_FOR_PW_TEXT,line)
-            || match(PROMPT_FOR_PW_TEXT2,line))
+        if ((match(PROMPT_FOR_PW_TEXT, line)
+            || match(PROMPT_FOR_PW_TEXT2, line))
            && !gotpassword)
         {
             gotpassword=1;
-            user_passwd(1);
-            term_echoing=FALSE;
-        };
+            user_passwd(true);
+            term_echoing=false;
+        }
         break;
     case 1:
-        if (match(PROMPT_FOR_MORE_TEXT,line))
+        if (match(PROMPT_FOR_MORE_TEXT, line))
         {
-            user_passwd(0);
-            got_more_kludge=1;
-        };
-    };
+            user_passwd(false);
+            got_more_kludge=true;
+        }
+    }
     _=line;
     PROF("processing incoming colors");
-    do_in_MUD_colors(line,0,ses);
-    isnb=isnotblank(line,0);
+    do_in_MUD_colors(line, false, ses);
+    isnb=isnotblank(line, false);
     PROF("promptactions");
     if (!ses->ignore && (nl||isnb))
         check_all_promptactions(line, ses);
@@ -920,15 +854,18 @@ static void do_one_line(char *line,int nl,struct session *ses)
     if (isnb&&!ses->togglesubs)
         do_all_high(line, ses);
     PROF("display");
-    if (isnotblank(line,ses->blank))
+    if (isnotblank(line, ses->blank))
     {
         if (ses==activesession)
         {
             if (nl)
             {
                 if (!activesession->server_echo)
+                {
+                    user_passwd(false);
                     gotpassword=0;
-                sprintf(strchr(line,0),"\n");
+                }
+                sprintf(strchr(line, 0), "\n");
                 user_textout_draft(0, 0);
                 user_textout(line);
                 lastdraft=0;
@@ -939,15 +876,14 @@ static void do_one_line(char *line,int nl,struct session *ses)
                 {
                     isnb = ses->gas ? ses->ga : iscompleteprompt(line);
                     if (ses->partial_line_marker)
-                        sprintf(strchr(line,0), "%s", ses->partial_line_marker);
+                        sprintf(strchr(line, 0), "%s", ses->partial_line_marker);
                     user_textout_draft(line, isnb);
                 }
                 lastdraft=ses;
             }
         }
-        else
-            if (ses->snoopstatus)
-                snoop(line,ses);
+        else if (ses->snoopstatus)
+            snoop(line, ses);
     }
     PROFPOP;
     _=0;
@@ -955,7 +891,7 @@ static void do_one_line(char *line,int nl,struct session *ses)
 
     if (nl)
     {
-        gettimeofday(&t2,0);
+        gettimeofday(&t2, 0);
         t2.tv_sec-=t1.tv_sec;
         t2.tv_usec-=t1.tv_usec;
         if (t2.tv_usec<0)
@@ -977,14 +913,15 @@ static void do_one_line(char *line,int nl,struct session *ses)
 /**********************************************************/
 /* snoop session ses - chop up lines and put'em in buffer */
 /**********************************************************/
-static void snoop(char *buffer, struct session *ses)
+static void snoop(const char *buffer, struct session *ses)
 {
-    tintin_printf(0,"%s%% %s\n",ses->name,buffer);
+    tintin_printf(0, "%s%% %s\n", ses->name, buffer);
 }
 
-static void echo_input(char *txt)
+static void echo_input(const char *txt)
 {
-    char out[BUFFER_SIZE],*cptr,*optr;
+    const char *cptr;
+    char out[BUFFER_SIZE], *optr;
     static int c=7;
 
     if (ui_own_output)
@@ -1019,22 +956,22 @@ static void echo_input(char *txt)
 /**********************************************************/
 static void myquitsig(int sig)
 {
-    struct session *sesptr, *t;
+    struct session *t;
     int err=errno;
 
-    for (sesptr = sessionlist; sesptr; sesptr = t)
+    for (struct session *ses = sessionlist; ses; ses = t)
     {
-        t = sesptr->next;
-        if (sesptr!=nullsession && !sesptr->closing)
+        t = ses->next;
+        if (ses!=nullsession && !ses->closing)
         {
-            sesptr->closing=1;
-            do_hook(sesptr, HOOK_ZAP, 0, 1);
-            sesptr->closing=0;
-            cleanup_session(sesptr);
+            ses->closing=1;
+            do_hook(ses, HOOK_ZAP, 0, true);
+            ses->closing=0;
+            cleanup_session(ses);
         }
     }
     activesession = nullsession;
-    do_hook(nullsession, HOOK_END, 0, 1);
+    do_hook(nullsession, HOOK_END, 0, true);
     activesession = NULL;
 
     if (ui_own_output)
@@ -1056,8 +993,7 @@ static void myquitsig(int sig)
         }
         user_done();
     }
-    else
-        if (tty)
-            user_textout("~7~\n");
+    else if (tty)
+        user_textout("~7~\n");
     exit(0);
 }
