@@ -1,4 +1,5 @@
 #include "tintin.h"
+#include "protos/globals.h"
 #include "protos/print.h"
 #include "protos/parse.h"
 #include "protos/utils.h"
@@ -6,29 +7,26 @@
 #include <sys/types.h>
 #include <regex.h>
 
-extern char tintin_char;
-extern pvars_t *pvars;  /* the %0, %1, %2,....%9 variables */
 
-extern struct session *if_command(char *arg, struct session *ses);
+extern struct session *if_command(const char *arg, struct session *ses);
 
-static int check_regexp(char *line, char *action, pvars_t *vars, int inside, struct session *ses)
+static bool check_regexp(char *line, char *action, pvars_t *vars, struct session *ses)
 {
     regex_t preg;
     regmatch_t pmatch[10];
-    int i;
 
-    if (regcomp(&preg,action,REG_EXTENDED))
+    if (regcomp(&preg, action, REG_EXTENDED))
     {
-        tintin_eprintf(ses,"#invalid regular expression: {%s}",action);
-        return 0;
+        tintin_eprintf(ses, "#invalid regular expression: {%s}", action);
+        return false;
     }
-    if (regexec(&preg,line,vars?10:0,pmatch,inside?REG_NOTBOL:0))
+    if (regexec(&preg, line, vars?10:0, pmatch, 0))
     {
         regfree(&preg);
-        return FALSE;
+        return false;
     }
     if (vars)
-        for (i = 0; i < 10; i++)
+        for (int i = 0; i < 10; i++)
         {
             if (pmatch[i].rm_so != -1)
             {
@@ -40,17 +38,17 @@ static int check_regexp(char *line, char *action, pvars_t *vars, int inside, str
                 (*vars)[i][0]=0;
         }
     regfree(&preg);
-    return TRUE;
+    return true;
 }
 
 /*********************/
 /* the #grep command */
 /*********************/
-void grep_command(char *arg, struct session *ses)
+void grep_command(const char *arg, struct session *ses)
 {
-    pvars_t vars,*lastpvars;
+    pvars_t vars, *lastpvars;
     char left[BUFFER_SIZE], line[BUFFER_SIZE], right[BUFFER_SIZE];
-    int flag=0;
+    bool flag=false;
 
     arg=get_arg(arg, left, 0, ses);
     arg=get_arg(arg, line, 0, ses);
@@ -58,17 +56,17 @@ void grep_command(char *arg, struct session *ses)
 
     if (!*left || !*right)
     {
-        tintin_eprintf(ses,"#ERROR: valid syntax is: #grep <pattern> <line> <command> [#else ...]");
+        tintin_eprintf(ses, "#ERROR: valid syntax is: #grep <pattern> <line> <command> [#else ...]");
         return;
     }
 
-    if (check_regexp(line, left, &vars, 0, ses))
+    if (check_regexp(line, left, &vars, ses))
     {
         lastpvars = pvars;
         pvars = &vars;
-        parse_input(right,1,ses);
+        parse_input(right, true, ses);
         pvars = lastpvars;
-        flag=1;
+        flag=true;
     }
     arg=get_arg_in_braces(arg, left, 0);
     if (*left == tintin_char)
@@ -77,7 +75,7 @@ void grep_command(char *arg, struct session *ses)
         {
             get_arg_in_braces(arg, right, 1);
             if (!flag)
-                parse_input(right,1,ses);
+                parse_input(right, true, ses);
             return;
         }
         if (is_abrev(left + 1, "elif"))
@@ -88,14 +86,14 @@ void grep_command(char *arg, struct session *ses)
         }
     }
     if (*left)
-        tintin_eprintf(ses,"#ERROR: cruft after #grep: {%s}",left);
+        tintin_eprintf(ses, "#ERROR: cruft after #grep: {%s}", left);
 }
 
 
 /********************/
 /* the #grep inline */
 /********************/
-int grep_inline(char *arg, struct session *ses)
+int grep_inline(const char *arg, struct session *ses)
 {
     char left[BUFFER_SIZE], line[BUFFER_SIZE];
 
@@ -104,10 +102,10 @@ int grep_inline(char *arg, struct session *ses)
 
     if (!*left)
     {
-        tintin_eprintf(ses,"#ERROR: valid syntax is: (#grep <pattern> <line>)");
+        tintin_eprintf(ses, "#ERROR: valid syntax is: (#grep <pattern> <line>)");
         return 0;
     }
-    return check_regexp(line, left, 0, 0, ses);
+    return check_regexp(line, left, 0, ses);
 }
 
 
