@@ -7,6 +7,7 @@
 #include "tintin.h"
 #include "protos/colors.h"
 #include "protos/files.h"
+#include "protos/globals.h"
 #include "protos/hash.h"
 #include "protos/hooks.h"
 #include "protos/llist.h"
@@ -16,9 +17,9 @@
 #include "protos/routes.h"
 #include "protos/run.h"
 #include "protos/unicode.h"
+#include "protos/user.h"
 #include "protos/utils.h"
 #include "protos/variables.h"
-#include "ui.h"
 #ifdef HAVE_GNUTLS
 #include "protos/ssl.h"
 #else
@@ -26,43 +27,36 @@
 #endif
 
 
-extern struct session *sessionlist, *activesession, *nullsession;
-extern char *history[HISTORY_SIZE];
-extern char *user_charset_name;
-extern int any_closed;
 #ifdef HAVE_GNUTLS
 #else
 # define gnutls_session_t int
 #endif
 
-static struct session *new_session(char *name, char *address, int sock, int issocket, gnutls_session_t ssl, struct session *ses);
+static struct session *new_session(const char *name, const char *address, int fd, bool issocket, gnutls_session_t ssl, struct session *ses);
 static void show_session(struct session *ses);
 
-static int session_exists(char *name)
+static bool session_exists(char *name)
 {
-    struct session *sesptr;
-
-    for (sesptr = sessionlist; sesptr; sesptr = sesptr->next)
+    for (struct session *sesptr = sessionlist; sesptr; sesptr = sesptr->next)
         if (!strcmp(sesptr->name, name))
-            return 1;
-    return 0;
+            return true;
+    return false;
 }
 
 /* FIXME: use non-ascii letters in generated names */
 
 /* NOTE: basis is in the local charset, not UTF-8 */
-void make_name(char *str, char *basis, int run)
+void make_name(char *str, const char *basis)
 {
     char *t;
-    int i,j;
+    int i, j;
 
-    if (run)
-        for (t=basis; (*t=='/')||is7alnum(*t)||(*t=='_'); t++)
-            if (*t=='/')
-                basis=t+1;
+    for (const char *b=basis; (*b=='/')||is7alnum(*b)||(*b=='_'); b++)
+        if (*b=='/')
+            basis=b+1;
     if (!is7alpha(*basis))
         goto noname;
-    strcpy(str, basis);
+    strlcpy(str, basis, MAX_SESNAME_LENGTH);
     for (t=str; is7alnum(*t)||(*t=='_'); t++);
     *t=0;
     if (!session_exists(str))
@@ -95,7 +89,7 @@ noname:
     #session {a}        - print info about session a
   (opposed to #session {a} {mud.address.here 666} - starting a new session)
 */
-static int list_sessions(char *arg,struct session *ses,char *left,char *right)
+static int list_sessions(const char *arg, struct session *ses, char *left, char *right)
 {
     struct session *sesptr;
     arg = get_arg_in_braces(arg, left, 0);
@@ -107,7 +101,6 @@ static int list_sessions(char *arg,struct session *ses,char *left,char *right)
         for (sesptr = sessionlist; sesptr; sesptr = sesptr->next)
             if (sesptr!=nullsession)
                 show_session(sesptr);
-        prompt(ses);
     }
     else if (*left && !*right)
     {
@@ -118,28 +111,29 @@ static int list_sessions(char *arg,struct session *ses,char *left,char *right)
                 break;
             }
         if (sesptr == NULL)
-        {
             tintin_puts("#THAT SESSION IS NOT DEFINED.", ses);
-            prompt(NULL);
-        }
     }
     else
     {
+        if (strlen(left) > MAX_SESNAME_LENGTH)
+        {
+            tintin_eprintf(ses, "#SESSION NAME TOO LONG.");
+            return 1;
+        }
         if (session_exists(left))
         {
-            tintin_eprintf(ses,"#THERE'S A SESSION WITH THAT NAME ALREADY.");
-            prompt(NULL);
+            tintin_eprintf(ses, "#THERE'S A SESSION WITH THAT NAME ALREADY.");
             return 1;
-        };
+        }
         return 0;
-    };
+    }
     return 1;
 }
 
 /*****************************************/
 /* the #session and #sslsession commands */
 /*****************************************/
-static struct session *socket_session(char *arg, struct session *ses, int ssl)
+static struct session *socket_session(const char *arg, struct session *ses, bool ssl)
 {
     char left[BUFFER_SIZE], right[BUFFER_SIZE], host[BUFFER_SIZE];
     int sock;
@@ -148,14 +142,14 @@ static struct session *socket_session(char *arg, struct session *ses, int ssl)
     gnutls_session_t sslses;
 #endif
 
-    if (list_sessions(arg,ses,left,right))
+    if (list_sessions(arg, ses, left, right))
         return ses;     /* (!*left)||(!*right) */
 
     strcpy(host, space_out(right));
 
     if (!*host)
     {
-        tintin_eprintf(ses,"#session: HEY! SPECIFY AN ADDRESS WILL YOU?");
+        tintin_eprintf(ses, "#session: HEY! SPECIFY AN ADDRESS WILL YOU?");
         return ses;
     }
 
@@ -165,7 +159,7 @@ static struct session *socket_session(char *arg, struct session *ses, int ssl)
     if (*port)
     {
         *port++ = '\0';
-        port = space_out(port);
+        port = (char*)space_out(port);
     }
 
     if (!*port)
@@ -184,22 +178,22 @@ static struct session *socket_session(char *arg, struct session *ses, int ssl)
             close(sock);
             return ses;
         }
-        return new_session(left, right, sock, 1, sslses, ses);
+        return new_session(left, right, sock, true, sslses, ses);
     }
 #endif
-    return new_session(left, right, sock, 1, 0, ses);
+    return new_session(left, right, sock, true, 0, ses);
 }
 
 
-struct session *session_command(char *arg, struct session *ses)
+struct session *session_command(const char *arg, struct session *ses)
 {
-    return socket_session(arg, ses, 0);
+    return socket_session(arg, ses, false);
 }
 
-struct session *sslsession_command(char *arg, struct session *ses)
+struct session *sslsession_command(const char *arg, struct session *ses)
 {
 #ifdef HAVE_GNUTLS
-    return socket_session(arg, ses, 1);
+    return socket_session(arg, ses, true);
 #else
     tintin_eprintf(ses, "#SSLSESSION is not supported.  Please recompile KBtin against GnuTLS.");
     return ses;
@@ -210,19 +204,19 @@ struct session *sslsession_command(char *arg, struct session *ses)
 /********************/
 /* the #run command */
 /********************/
-struct session *run_command(char *arg,struct session *ses)
+struct session *run_command(const char *arg, struct session *ses)
 {
     char left[BUFFER_SIZE], right[BUFFER_SIZE], ustr[BUFFER_SIZE];
     int sock;
 
-    if (list_sessions(arg,ses,left,right))
+    if (list_sessions(arg, ses, left, right))
         return ses;     /* (!*left)||(!*right) */
 
     if (!*right)
     {
         tintin_eprintf(ses, "#run: HEY! SPECIFY A COMMAND, WILL YOU?");
         return ses;
-    };
+    }
 
     utf8_to_local(ustr, right);
     if ((sock=run(ustr, COLS, LINES-1, TERM)) == -1)
@@ -231,7 +225,7 @@ struct session *run_command(char *arg,struct session *ses)
         return ses;
     }
 
-    return new_session(left, right, sock, 0, 0, ses);
+    return new_session(left, right, sock, false, 0, ses);
 }
 
 
@@ -240,17 +234,10 @@ struct session *run_command(char *arg,struct session *ses)
 /******************/
 static void show_session(struct session *ses)
 {
-    char temp[BUFFER_SIZE];
-
-    sprintf(temp, "%-10s{%s}", ses->name, ses->address);
-
-    if (ses == activesession)
-        strcat(temp, " (active)");
-    if (ses->snoopstatus)
-        strcat(temp, " (snooped)");
-    if (ses->logfile)
-        strcat(temp, " (logging)");
-    tintin_printf(0, "%s", temp);
+    tintin_printf(0, "%-10s{%s}%s%s%s", ses->name, ses->address,
+        ses == activesession ? " (active)":"",
+        ses->snoopstatus ? " (snooped)":"",
+        ses->logfile ? " (logging)":"");
 }
 
 /**********************************/
@@ -266,13 +253,13 @@ struct session *newactive_session(void)
 
         sprintf(buf, "#SESSION '%s' ACTIVATED.", activesession->name);
         tintin_puts1(buf, activesession);
-        return do_hook(activesession, HOOK_ACTIVATE, 0, 0);
+        return do_hook(activesession, HOOK_ACTIVATE, 0, false);
     }
     else
     {
         activesession=nullsession;
         tintin_puts1("#THERE'S NO ACTIVE SESSION NOW.", activesession);
-        return do_hook(activesession, HOOK_ACTIVATE, 0, 0);
+        return do_hook(activesession, HOOK_ACTIVATE, 0, false);
     }
 }
 
@@ -280,20 +267,19 @@ struct session *newactive_session(void)
 /**********************/
 /* open a new session */
 /**********************/
-static struct session *new_session(char *name, char *address, int sock, int issocket, gnutls_session_t ssl, struct session *ses)
+static struct session *new_session(const char *name, const char *address, int sock, bool issocket, gnutls_session_t ssl, struct session *ses)
 {
     struct session *newsession;
-    int i;
 
     newsession = TALLOC(struct session);
 
     newsession->name = mystrdup(name);
     newsession->address = mystrdup(address);
-    newsession->tickstatus = FALSE;
+    newsession->tickstatus = false;
     newsession->tick_size = ses->tick_size;
     newsession->pretick = ses->pretick;
     newsession->time0 = 0;
-    newsession->snoopstatus = 0;
+    newsession->snoopstatus = false;
     newsession->logfile = 0;
     newsession->logname = 0;
     newsession->logtype = ses->logtype;
@@ -313,12 +299,12 @@ static struct session *new_session(char *name, char *address, int sock, int isso
     newsession->issocket = issocket;
     newsession->naws = !issocket;
 #ifdef HAVE_ZLIB
-    newsession->can_mccp = 0;
+    newsession->can_mccp = false;
     newsession->mccp = 0;
-    newsession->mccp_more = 0;
+    newsession->mccp_more = false;
 #endif
-    newsession->ga = 0;
-    newsession->gas = 0;
+    newsession->ga = false;
+    newsession->gas = false;
     newsession->server_echo = 0;
     newsession->telnet_buflen = 0;
     newsession->last_term_type = 0;
@@ -326,7 +312,7 @@ static struct session *new_session(char *name, char *address, int sock, int isso
     newsession->path = init_list();
     newsession->no_return = 0;
     newsession->path_length = 0;
-    newsession->more_coming = 0;
+    newsession->more_coming = false;
     newsession->events = NULL;
     newsession->verbose = ses->verbose;
     newsession->blank = ses->blank;
@@ -337,22 +323,23 @@ static struct session *new_session(char *name, char *address, int sock, int isso
     newsession->verbatim = ses->verbatim;
     newsession->sessionstart=newsession->idle_since=
         newsession->server_idle_since=time(0);
-    newsession->nagle=0;
-    newsession->halfcr_in=0;
-    newsession->halfcr_log=0;
+    newsession->nagle=false;
+    newsession->halfcr_in=false;
+    newsession->halfcr_log=false;
     newsession->lastintitle=0;
     newsession->debuglogfile=0;
     newsession->debuglogname=0;
     newsession->partial_line_marker = mystrdup(ses->partial_line_marker);
-    memcpy(newsession->mesvar, ses->mesvar, sizeof(int)*(MAX_MESVAR+1));
-    for (i=0;i<MAX_LOCATIONS;i++)
+    for (int i=0;i<=MAX_MESVAR;i++)
+        newsession->mesvar[i] = ses->mesvar[i];
+    for (int i=0;i<MAX_LOCATIONS;i++)
     {
         newsession->routes[i]=0;
         newsession->locations[i]=0;
-    };
-    copyroutes(ses,newsession);
+    }
+    copyroutes(ses, newsession);
     newsession->last_line[0]=0;
-    for (i=0;i<NHOOKS;i++)
+    for (int i=0;i<NHOOKS;i++)
         if (ses->hooks[i])
             newsession->hooks[i]=mystrdup(ses->hooks[i]);
         else
@@ -372,7 +359,7 @@ static struct session *new_session(char *name, char *address, int sock, int isso
     sessionlist = newsession;
     activesession = newsession;
 
-    return do_hook(newsession, HOOK_OPEN, 0, 0);
+    return do_hook(newsession, HOOK_OPEN, 0, false);
 }
 
 
@@ -381,17 +368,16 @@ static struct session *new_session(char *name, char *address, int sock, int isso
 /*****************************************************************************/
 void cleanup_session(struct session *ses)
 {
-    int i;
-    char buf[BUFFER_SIZE];
+    char buf[BUFFER_SIZE+1];
     struct session *sesptr, *act;
 
     if (ses->closing)
         return;
-    any_closed=1;
+    any_closed=true;
     ses->closing=2;
-    do_hook(act=ses, HOOK_CLOSE, 0, 1);
+    do_hook(act=ses, HOOK_CLOSE, 0, true);
 
-    kill_all(ses, END);
+    kill_all(ses, true);
     if (ses == sessionlist)
         sessionlist = ses->next;
     else
@@ -402,11 +388,11 @@ void cleanup_session(struct session *ses)
     if (ses==activesession)
     {
         user_textout_draft(0, 0);
-        sprintf(buf,"%s\n",ses->last_line);
+        sprintf(buf, "%s\n", ses->last_line);
         convert(&ses->c_io, ses->last_line, buf, -1);
-        do_in_MUD_colors(ses->last_line,0,0);
+        do_in_MUD_colors(ses->last_line, false, 0);
         user_textout(ses->last_line);
-    };
+    }
     sprintf(buf, "#SESSION '%s' DIED.", ses->name);
     tintin_puts(buf, NULL);
     if (close(ses->socket) == -1)
@@ -417,7 +403,7 @@ void cleanup_session(struct session *ses)
         fclose(ses->debuglogfile);
     SFREE(ses->loginputprefix);
     SFREE(ses->loginputsuffix);
-    for (i=0;i<NHOOKS;i++)
+    for (int i=0;i<NHOOKS;i++)
         SFREE(ses->hooks[i]);
     SFREE(ses->name);
     SFREE(ses->address);
@@ -443,27 +429,26 @@ void cleanup_session(struct session *ses)
 
 void seslist(char *result)
 {
-    struct session *sesptr;
-    int flag=0;
+    bool flag=false;
     char *r0=result;
 
-    if ((sessionlist!=nullsession)||(nullsession->next))
-    {
-        for (sesptr = sessionlist; sesptr; sesptr = sesptr->next)
-            if (sesptr!=nullsession)
-            {
-                if (flag)
-                    *result++=' ';
-                else
-                    flag=1;
-                if (isatom(sesptr->name))
-                    result+=snprintf(result, BUFFER_SIZE-5+r0-result,
-                        "%s",sesptr->name);
-                else
-                    result+=snprintf(result, BUFFER_SIZE-5+r0-result,
-                        "{%s}",sesptr->name);
-                if (result-r0>BUFFER_SIZE-10)
-                    return; /* pathological session names */
-            }
-    }
+    if (sessionlist==nullsession && !nullsession->next)
+        return;
+
+    for (struct session *sesptr = sessionlist; sesptr; sesptr = sesptr->next)
+        if (sesptr!=nullsession)
+        {
+            if (flag)
+                *result++=' ';
+            else
+                flag=true;
+            if (isatom(sesptr->name))
+                result+=snprintf(result, BUFFER_SIZE-5+r0-result,
+                    "%s", sesptr->name);
+            else
+                result+=snprintf(result, BUFFER_SIZE-5+r0-result,
+                    "{%s}", sesptr->name);
+            if (result-r0>BUFFER_SIZE-10)
+                return; /* pathological session names */
+        }
 }
