@@ -1,18 +1,12 @@
 /******************************************************************/
 /* file: tintin.h - the include file for KBtin                    */
 /******************************************************************/
-#define UTF8                /* UTF8 support */
-
 #undef TELNET_DEBUG     /* define to show TELNET negotiations */
 #undef USER_DEBUG       /* debugging of the user interface */
 #undef TERM_DEBUG       /* debugging pseudo-tty stuff */
 #undef PROFILING        /* profiling */
 
-/************************/
-/* The meaning of life: */
-/************************/
-#define TRUE 1
-#define FALSE 0
+#include <stdbool.h>
 
 /**********************/
 /* color ANSI numbers */
@@ -42,7 +36,7 @@
 /************************************************************************/
 
 #ifndef COMPRESSED_HELP
-#define COMPRESSED_HELP TRUE
+#define COMPRESSED_HELP 1
 #endif
 
 /***********************************************/
@@ -53,23 +47,20 @@
 #define INPUT_COLOR  COLOR_BLUE
 #define MARGIN_COLOR COLOR_RED
 /* FIXME: neither INPUT_COLOR nor MARGIN_COLOR can be COLOR_WHITE */
-/*#define GRAY2 */    /* if you have problems with the dark gray (~8~) color */
 /*#define IGNORE_INT*//* uncomment to disable INT (usually ^C) from keyboard */
 /*#define BARE_ESC*/  /* uncomment to allow use of bare ESC key.  It will
                          prevent Alt-XXX from being recognized, though. */
 #define XTERM_TITLE "KBtin - %s"
 #undef  PTY_ECHO_HACK   /* not working yet */
-#define ASSUME_UTF8 0      /* if character width cannot be autodetected */
 #define ECHO_COLOR "~8~"
 #define LOG_INPUT_PREFIX "" /* you can add ANSI codes, etc here */
 #define LOG_INPUT_SUFFIX ""
 #define RESET_RAW       /* reset pseudo-terminals to raw mode every write */
 #define GOTO_CHAR '>'   /* be>mt -> #goto be mt */
                         /*Comment last line out to disable this behavior */
-#define OLD_LOG 0 /* set to one to use old-style logging */
-#define DEFAULT_LOGTYPE (1-OLD_LOG)       /* 0: cr/lf, 1: lf, 2: ttyrec */
-#define DEFAULT_OPEN '{' /*character that starts an argument */
-#define DEFAULT_CLOSE '}' /*character that ends an argument */
+#define DEFAULT_LOGTYPE LOG_LF    /* LOG_RAW: cr/lf or what server sends, LOG_LF: lf, LOG_TTYREC */
+#define BRACE_OPEN '{' /*character that starts an argument */
+#define BRACE_CLOSE '}' /*character that ends an argument */
 #define HISTORY_SIZE 128                  /* history size */
 #define MAX_PATH_LENGTH 256               /* max path length (#route) */
 #define MAX_LOCATIONS 2048
@@ -79,6 +70,7 @@
 #define DEFAULT_VERBATIM_CHAR '\\'        /* if an input starts with this
                                              char, it will be sent 'as is'
                                              to the MUD */
+#define MAX_SESNAME_LENGTH 512 /* don't accept session names longer than this */
 #ifdef __FreeBSD__
 #define MAX_RECURSION 64
 #else
@@ -88,40 +80,40 @@
 #define DEFAULT_FILE_DIR "." /* Path to Tintin files, or HOME */
 #endif
 #if COMPRESSED_HELP
-#define DEFAULT_COMPRESSION_EXT ".gz"     /* for compress: ".Z" */
-#define DEFAULT_EXPANSION_STR "gzip -cd " /* for compress: "uncompress -c" */
+#define COMPRESSION_EXT ".gz"      /* for compress: ".Z" */
+#define UNCOMPRESS_CMD "gzip -cd " /* for compress: "uncompress -c" */
 #else
-#define DEFAULT_COMPRESSION_EXT ""
+#define COMPRESSION_EXT ""
 #endif
 #define NEWS_FILE   "NEWS"
 #define CONFIG_DIR ".tintin"
 #define CERT_DIR   "ssl"
 
-#define DEFAULT_DISPLAY_BLANK TRUE        /* blank lines */
-#define DEFAULT_ECHO_SEPINPUT TRUE        /* echo when there is an input box */
-#define DEFAULT_ECHO_NOSEPINPUT FALSE     /* echo when input is not managed */
-#define DEFAULT_IGNORE FALSE              /* ignore */
-#define DEFAULT_SPEEDWALK FALSE           /* speedwalk */
+#define DEFAULT_DISPLAY_BLANK true        /* blank lines */
+#define DEFAULT_ECHO_SEPINPUT true        /* echo when there is an input box */
+#define DEFAULT_ECHO_NOSEPINPUT false     /* echo when input is not managed */
+#define DEFAULT_IGNORE false              /* ignore */
+#define DEFAULT_SPEEDWALK false           /* speedwalk */
         /* note: classic speedwalks are possible only on some primitive
            MUDs with only 4 basic directions (w,e,n,s)                   */
-#define DEFAULT_PRESUB FALSE              /* presub before actions */
-#define DEFAULT_TOGGLESUBS FALSE          /* turn subs on and off FALSE=ON*/
-#define DEFAULT_KEYPAD FALSE              /* start in standard keypad mode */
-#define DEFAULT_RETAIN FALSE              /* retain the last typed line */
-#define DEFAULT_ALIAS_MESS TRUE           /* messages for responses */
-#define DEFAULT_ACTION_MESS TRUE          /* when setting/deleting aliases, */
-#define DEFAULT_SUB_MESS TRUE             /* actions, etc. may be set to */
-#define DEFAULT_HIGHLIGHT_MESS TRUE       /* default either on or off */
-#define DEFAULT_VARIABLE_MESS TRUE        /* might want to turn off these */
-#define DEFAULT_EVENT_MESS TRUE
-#define DEFAULT_ROUTE_MESS TRUE
-#define DEFAULT_GOTO_MESS TRUE
-#define DEFAULT_BIND_MESS TRUE
-#define DEFAULT_SYSTEM_MESS TRUE
-#define DEFAULT_PATH_MESS TRUE
-#define DEFAULT_ERROR_MESS TRUE
-#define DEFAULT_HOOK_MESS TRUE
-#define DEFAULT_LOG_MESS TRUE
+#define DEFAULT_PRESUB false              /* presub before actions */
+#define DEFAULT_TOGGLESUBS false          /* turn subs on and off FALSE=ON*/
+#define DEFAULT_KEYPAD false              /* start in standard keypad mode */
+#define DEFAULT_RETAIN false              /* retain the last typed line */
+#define DEFAULT_ALIAS_MESS true           /* messages for responses */
+#define DEFAULT_ACTION_MESS true          /* when setting/deleting aliases, */
+#define DEFAULT_SUB_MESS true             /* actions, etc. may be set to */
+#define DEFAULT_HIGHLIGHT_MESS true       /* default either on or off */
+#define DEFAULT_VARIABLE_MESS true        /* might want to turn off these */
+#define DEFAULT_EVENT_MESS true
+#define DEFAULT_ROUTE_MESS true
+#define DEFAULT_GOTO_MESS true
+#define DEFAULT_BIND_MESS true
+#define DEFAULT_SYSTEM_MESS true
+#define DEFAULT_PATH_MESS true
+#define DEFAULT_ERROR_MESS true
+#define DEFAULT_HOOK_MESS true
+#define DEFAULT_LOG_MESS true
 #define DEFAULT_PRETICK 10
 #define DEFAULT_CHARSET "ISO-8859-1"      /* the MUD-side charset */
 #define DEFAULT_LOGCHARSET LOGCS_LOCAL
@@ -130,17 +122,6 @@
 #define CHAR_VERBATIM '\\'
 #define CHAR_QUOTE '"'
 #define CHAR_NEWLINE ';'
-/**************************************************************************/
-/* Should a prompt appear whenever TINTIN has written something to the    */
-/* screen?                                                                */
-/**************************************************************************/
-#define FORCE_PROMPT FALSE
-/**************************************************************************/
-/* Whenever TINTIN has written something to the screen, the program sends */
-/* a CR/LF to the MUD to force a new prompt to appear. You can have       */
-/* TINTIN print it's own pseudo prompt instead.                           */
-/**************************************************************************/
-#define PSEUDO_PROMPT FALSE
 /*************************************************************************/
 /* The text below is checked for. If it trickers then echo is turned off */
 /* echo is turned back on the next time the user types a return          */
@@ -166,41 +147,41 @@
 /* The stuff below here shouldn't be modified unless you know what you're */
 /* doing........                                                          */
 /**************************************************************************/
-#define STOP_AT_SPACES 0
-#define WITH_SPACES 1
-#define ALPHA 1
-#define PRIORITY 0
-#define LENGTH 2
-#define CLEAN 0
-#define END 1
+typedef enum {PRIORITY, ALPHA, LENGTH} llist_mode_t;
 #define K_ACTION_MAGIC "#X~4~~2~~12~[This action is being deleted!]~7~X"
 
 #define BUFFER_SIZE 4096
 #define INPUT_CHUNK 1536
-#define MSG_ALIAS       0
-#define MSG_ACTION      1
-#define MSG_SUBSTITUTE  2
-#define MSG_EVENT       3
-#define MSG_HIGHLIGHT   4
-#define MSG_VARIABLE    5
-#define MSG_ROUTE       6
-#define MSG_GOTO        7
-#define MSG_BIND        8
-#define MSG_SYSTEM      9
-#define MSG_PATH        10
-#define MSG_ERROR       11
-#define MSG_HOOK        12
-#define MSG_LOG         13
-#define MAX_MESVAR      14
-#define HOOK_OPEN       0
-#define HOOK_CLOSE      1
-#define HOOK_ZAP        2
-#define HOOK_END        3
-#define HOOK_SEND       4
-#define HOOK_ACTIVATE   5
-#define HOOK_DEACTIVATE 6
-#define HOOK_TITLE      7
-#define NHOOKS          8
+enum
+{
+    MSG_ALIAS,
+    MSG_ACTION,
+    MSG_SUBSTITUTE,
+    MSG_EVENT,
+    MSG_HIGHLIGHT,
+    MSG_VARIABLE,
+    MSG_ROUTE,
+    MSG_GOTO,
+    MSG_BIND,
+    MSG_SYSTEM,
+    MSG_PATH,
+    MSG_ERROR,
+    MSG_HOOK,
+    MSG_LOG,
+    MAX_MESVAR
+};
+enum
+{
+    HOOK_OPEN,
+    HOOK_CLOSE,
+    HOOK_ZAP,
+    HOOK_END,
+    HOOK_SEND,
+    HOOK_ACTIVATE,
+    HOOK_DEACTIVATE,
+    HOOK_TITLE,
+    NHOOKS
+};
 
 /************************ includes *********************/
 #define _GNU_SOURCE
@@ -211,6 +192,7 @@
 #include <ctype.h>
 #include <wctype.h>
 #include "malloc.h"
+#include "unicode.h"
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdarg.h>
@@ -248,12 +230,6 @@
 # include <gnutls/gnutls.h>
 # include <gnutls/x509.h>
 #endif
-#ifndef HAVE_SNPRINTF
-int snprintf(char *str, int len, char *fmt, ...);
-#endif
-#ifndef HAVE_VSNPRINTF
-int vsnprintf(char *str, int len, char *fmt, va_list ap);
-#endif
 #ifndef HAVE_STRLCPY
 size_t strlcpy(char *dst, const char *src, size_t n);
 #endif
@@ -301,29 +277,33 @@ struct routenode
     char *cond;
 };
 
+typedef enum { CM_ISO8859_1, CM_UTF8, CM_ICONV, CM_ASCII } conv_mode_t;
+
 struct charset_conv
 {
-    char *name;
-    int mode; /* 0=8bit, 1=UTF-8, 2=iconv */
+    const char *name;
+    conv_mode_t mode;
     int dir; /* -1=only in, 0=both, 1=only out */
     iconv_t i_in, i_out;
 };
 
+typedef enum { LOG_RAW, LOG_LF, LOG_TTYREC } logtype_t;
+
 struct session
 {
     struct session *next;
     char *name;
     char *address;
-    int tickstatus;
+    bool tickstatus;
     time_t time0;      /* time of last tick (adjusted every tick) */
     time_t time10;
-    int tick_size,pretick;
-    int snoopstatus;
-    FILE *logfile,*debuglogfile;
-    char *logname,*debuglogname;
+    int tick_size, pretick;
+    bool snoopstatus;
+    FILE *logfile, *debuglogfile;
+    char *logname, *debuglogname;
     char *loginputprefix, *loginputsuffix;
-    int logtype;
-    int ignore;
+    logtype_t logtype;
+    bool ignore;
     struct listnode *actions, *prompts, *subs, *highs, *antisubs;
     struct hashtable *aliases, *myvars, *pathdirs, *binds;
     struct listnode *path;
@@ -331,27 +311,27 @@ struct session
     char *locations[MAX_LOCATIONS];
     struct eventnode *events;
     int path_length, no_return;
-    int socket, issocket, naws, ga, gas, last_term_type;
+    int socket, last_term_type;
+    bool issocket, naws, ga, gas;
     int server_echo; /* 0=not negotiated, 1=we shouldn't echo, 2=we can echo */
-    int more_coming;
-    char last_line[BUFFER_SIZE],telnet_buf[BUFFER_SIZE];
+    bool more_coming;
+    char last_line[BUFFER_SIZE], telnet_buf[BUFFER_SIZE];
     int telnet_buflen;
-    int verbose,blank,echo,speedwalk,togglesubs,presub,verbatim;
+    bool verbose, blank, echo, speedwalk, togglesubs, presub, verbatim;
     char *partial_line_marker;
-    int mesvar[MAX_MESVAR+1];
+    bool mesvar[MAX_MESVAR+1];
     time_t idle_since, server_idle_since;
-    int sessionstart;
+    time_t sessionstart;
     char *hooks[NHOOKS];
     int closing;
     int nagle;
-    int halfcr_in, halfcr_log; /* \r at the end of a packet */
+    bool halfcr_in, halfcr_log; /* \r at the end of a packet */
     int lastintitle;
     char *charset, *logcharset;
-    struct charset_conv c_io,c_log;
+    struct charset_conv c_io, c_log;
 #ifdef HAVE_ZLIB
-    int can_mccp;
+    bool can_mccp, mccp_more;
     z_stream *mccp;
-    int mccp_more;
     char mccp_buf[INPUT_CHUNK];
 #endif
 #ifdef HAVE_GNUTLS
@@ -364,9 +344,9 @@ typedef char pvars_t[10][BUFFER_SIZE];
 
 #ifdef PROFILING
 # define PROF(x) prof_area=(x)
-# define PROFPUSH(x) {char *prev_prof=prof_area; prof_area=(x)
+# define PROFPUSH(x) {const char *prev_prof=prof_area; prof_area=(x)
 # define PROFPOP prof_area=prev_prof;}
-# define PROFSTART struct timeval tvstart,tvend;gettimeofday(&tvstart,0);
+# define PROFSTART struct timeval tvstart, tvend;gettimeofday(&tvstart,0);
 # define PROFEND(x,y) gettimeofday(&tvend,0);(x)+=(tvend.tv_sec-tvstart.tv_sec) \
     *1000000+tvend.tv_usec-tvstart.tv_usec;(y)++;
 #else
@@ -404,23 +384,30 @@ struct ttyrec_header
                            (x))
 
 /* Chinese rod numerals are _not_ digits for our purposes. */
-#define isadigit(x) ((x)>='0' && (x)<='9')
+static inline bool isadigit(WC x) { return x>='0' && x<='9'; }
 /* Solaris is buggy for high-bit chars in UTF-8. */
-#define isaspace(x) ((x)==' ' || (x)=='\t' || (x)=='\n' || (x)==12 || (x)=='\v')
+static inline bool isaspace(WC x) { return x==' ' || x=='\t' || x=='\n' || x==12 || x=='\v'; }
 #define iswadigit(x) isadigit(x)
-/* Japanese/Chinese double-width chars.  We can't use wcwidth() as that's
-   a GNU extension.  The code below is buggy as it should return 0 for
-   non-printables, but nyah... */
-#define isw2width(x) ((x)>=0x1100  && ((x)<=0x11ff ||   \
-                      (x)>=0x2e80) && ((x)<=0xd7ff ||   \
-                      (x)>=0xf900) && ((x)<=0xfaff ||   \
-                      (x)>=0xfe30) && ((x)<=0xfe6f ||   \
-                      (x)>=0xff01) && ((x)<=0xff60 ||   \
-                      (x)>=0xffe0) && ((x)<=0xffe6 ||   \
-                      (x)>=0x20000) && (x)<=0x2ffff)
-#define is7alpha(x) ((((x)>='A')&&((x)<='Z')) || (((x)>='a')&&((x)<='z')))
-#define is7alnum(x) ((((x)>='0')&&((x)<='9')) || is7alpha(x))
+static inline bool isw2width(WC x)
+{
+    return x>=0x1100  && (x<=0x11ff ||
+           x==0x2329 || x==0x232a   ||
+           x>=0x2e80) && x!=0x303f
+                      && (x<=0xa4cf ||
+           x>=0xac00) && (x<=0xd7ff ||
+           x>=0xf900) && (x<=0xfaff ||
+           x>=0xfe30) && (x<=0xfe6f ||
+           x>=0xff00) && (x<=0xff60 ||
+           x>=0xffe0) && (x<=0xffe6 ||
+           x>=0x20000) && x<=0x3ffff;
+}
+
+static inline bool is7alpha(WC x) { return (x>='A'&&x<='Z') || (x>='a'&&x<='z'); }
+static inline bool is7alnum(WC x) { return (x>='0'&&x<='9') || is7alpha(x); }
+static inline char toalower(char x) { return (x>='A' && x<='Z') ? x+32 : x; }
 #define EMPTY_CHAR 0xffff
+#define VALID_TIN_CHARS "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~"
+#define is7punct(x) strchr(VALID_TIN_CHARS, (x))
 
 #define write_stdout(x, len) do if (write(1, (x), (len))!=(len)) \
                                   syserr("write to stdout failed"); while (0)
